@@ -6,17 +6,17 @@ to_any_case("veryComplicatedString")
 to_any_case("malte.grosser@gmail.com")
 
 ## ---- collapse = TRUE----------------------------------------------------
-to_any_case(names(iris), preprocess = "\\.")
+to_any_case(names(iris), sep_in = "\\.")
 
 ## ---- collapse = TRUE----------------------------------------------------
-to_any_case("Pi.Value:3.14", preprocess = ":|(?<!\\d)\\.")
+to_any_case("Pi.Value:3.14", sep_in = ":|(?<!\\d)\\.")
 
 ## ---- collapse = TRUE----------------------------------------------------
-to_any_case(names(iris), preprocess = "\\.", case = "upper_camel", postprocess = " ")
+to_any_case(names(iris), sep_in = "\\.", case = "upper_camel", sep_out = " ")
 
 ## ---- collapse = TRUE----------------------------------------------------
 to_any_case("Doppelgnger is originally german", 
-            replace_special_characters = "german", case = "upper_camel")
+            transliterations = "german", case = "upper_camel")
 
 ## ---- collapse = TRUE----------------------------------------------------
 to_any_case("THISIsHOW IAmPARSED!", case = "parsed")
